wheel
=====

`User list <http://groups.google.com/group/python-virtualenv>`_ |
`Dev list <https://mail.python.org/archives/list/distutils-sig@python.org/>`_ |
`GitHub <https://github.com/pypa/wheel>`_ |
`PyPI <https://pypi.org/pypi/wheel/>`_ |
User IRC: #pypa |
Dev IRC: #pypa-dev

This library is the reference implementation of the Python wheel packaging
standard, as defined in `PEP 427`_.

It has two different roles:

#. A setuptools_ extension for building wheels that provides the
   ``bdist_wheel`` setuptools command
#. A command line tool for working with wheel files

.. _PEP 427: https://www.python.org/dev/peps/pep-0427/
.. _setuptools: https://pypi.org/project/setuptools/

.. toctree::
   :maxdepth: 2

   quickstart
   installing
   user_guide
   reference/index
   development
   news
